package example;

/**
 * This classes stores an association between the name of a property and the value associated to it.
 * The name and the value of a property can only keep String objects.
 */
public class Pair implements Comparable<Pair> {

    private String name, value;

    /** 
     * Creates a new instance of Pair with a given name and value.
     * 
     * @param name is the name associated with this pair.
     * @param value is the value associated with this pair.
     */
    public Pair(String name, String value) {
        this.name = name;
        this.value = value;
    }

    /**
     * Compares two Pair objects.
     * @see java.lang.Comparable#compareTo(java.lang.Object)
     */
    public int compareTo(Pair other) {
        int res = this.name.compareTo(other.getName());

        if(res == 0)
            res = this.value.compareTo( other.getValue());

        return res;
    }


    /**
     * Returns a string representing the content of this Pair object.
     * 
     * @returns a String containing "name"="value"
     */
    public String toString() {
        return new String(name + "=" + value);
    }

    /**
     * @return a String containing the name associated with this Pair object.
     */
    public String getName() {
        return name;
    }

    /**
     * Changes the name associated with this Pair object.
     * 
     * @param name the new name associated to this Pair object.
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * @return a String containing the value associated with this Pair object.
     */
     public String getValue() {
        return value;
    }

    /**
     * Changes the value associated with this Pair object.
     * 
     * @param value the new value associated to this Pair object.
     */
    public void setValue(String value) {
        this.value = value;
    }
}